[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]



## About The Project

Cross-platform calculator



## Install

[Recommended](https://peps.python.org/pep-0668/):

```sh
pipx install xcalculator
```

Otherwise:

```sh
pip install xcalculator
```

On macOS, you may need:

```sh
brew install python-tk
```



## Run

```sh
xcalc
```

```sh
xcalculator
```



## License

Distributed under the MIT License. See [LICENSE](https://github.com/jacob-thompson/xcalculator/blob/main/LICENSE) for more information.



## Project Links

Github - [jacob-thompson/xcalculator](https://github.com/jacob-thompson/xcalculator)

PyPI - [xcalculator](https://pypi.org/project/xcalculator/)



## Contact

Jacob Alexander Thompson - jacobalthompson@gmail.com



[contributors-shield]: https://img.shields.io/github/contributors/jacob-thompson/xcalculator.svg?style=flat
[contributors-url]: https://github.com/jacob-thompson/xcalculator/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/jacob-thompson/xcalculator.svg?style=flat
[forks-url]: https://github.com/jacob-thompson/xcalculator/network/members
[stars-shield]: https://img.shields.io/github/stars/jacob-thompson/xcalculator.svg?style=flat
[stars-url]: https://github.com/jacob-thompson/xcalculator/stargazers
[issues-shield]: https://img.shields.io/github/issues/jacob-thompson/xcalculator.svg?style=flat
[issues-url]: https://github.com/jacob-thompson/xcalculator/issues
[license-shield]: https://img.shields.io/github/license/jacob-thompson/xcalculator.svg?style=flat
[license-url]: https://github.com/jacob-thompson/xcalculator/blob/main/LICENSE